@@ -2,7 +2,7 @@ package Sisimai;
 use v5.26;
 use strict;
 use warnings;
-use version; our $VERSION = version->declare('v5.1.0'); our $PATCHLV = 0;
+use version; our $VERSION = version->declare('v5.2.1'); our $PATCHLV = 0;
 sub version { return substr($VERSION->stringify, 1).($PATCHLV > 0 ? 'p'.$PATCHLV : '') }
 sub libname { 'Sisimai' }
 
@@ -70,6 +70,10 @@ sub dump {
         # Set UTF8 flag before converting to JSON string
         utf8::decode $e->{'subject'};
         utf8::decode $e->{'diagnosticcode'};
+
+        # Backward compatibility until v5.5.0
+        $e->{"smtpagent"} = $e->{"decodedby"};
+        $e->{"smtpcommand"} = $e->{"command"};
     }
 
     require Module::Load;
@@ -387,7 +391,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2025 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
