@@ -1,6 +1,6 @@
 package Sisimai::Lhost::X6;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -10,7 +10,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.25.6
     my $class = shift;
     my $mhead = shift // return undef;
@@ -98,7 +98,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::X6 - bounce mail parser class for C<X6>.
+Sisimai::Lhost::X6 - bounce mail decoder class for C<X6>.
 
 =head1 SYNOPSIS
 
@@ -106,8 +106,8 @@ Sisimai::Lhost::X6 - bounce mail parser class for C<X6>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::X6 parses a bounce email which created by Unknown MTA #6. Methods in the module are
-called from only Sisimai::Message.
+C<Sisimai::Lhost::X6> decodes a bounce email which created by Unknown MTA #6. Methods in the module
+are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -119,8 +119,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -128,7 +128,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2020,2021,2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2020,2021,2023,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
